View source: R/tvGarchKalmanLoglike.R
| tvGarchKalmanLoglike | R Documentation |
It is the function to use in the process to fit coefficients.
tvGarchKalmanLoglike(
x,
series,
c,
alpha,
beta,
nsample = length(series),
type = c("polynomial", "NoLineal", "trigonometric"),
exponentes,
trig,
arg,
predict,
trace.log = FALSE
)
x |
Vector of coefficents to fit. |
series |
Time series. |
c |
Vector containing coefficents of c. |
alpha |
Vector containing coefficents of alpha. |
beta |
Vector containing coefficents of beta. |
nsample |
Value of time series length. |
type |
Vector of function type for c, alpha and beta. |
exponentes |
Vector for exponenets in NoLineal. |
trig |
Type of trigonometric function. |
arg |
Value of argument for the trigonometric function. |
predict |
Value for time to generate predict. |
trace.log |
Variable to print names of coefficients. |
Value of loglike in model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.